pub struct ProgressBar { /* private fields */ }Expand description
The default progress bar
The exact format is decided at run time depending on whether we are writing to an interactive terminal or a non-interactive output.
Implementations